# nhc
> Niko Home Control library for python

## features
- [x] get all actions (lights, covers & fans)
- [x] get lights
- [x] get covers
- [x] get fans
- [ ] get energy
- [ ] get thermostats
- [x] event callback
- [x] suggested area (locations defined in the controller)

## shout-out
[@jeroenvaes](https://github.com/jeroenvaes) for debugging, fixes and the addition of the event callback!
&
[@Peacem4kr](https://github.com/Peacem4kr) for opening his port ;)

